@@ -3,12 +3,13 @@ import os
 import re
 from typing import Dict
 
-from ddb.config import config
-from ddb.feature.traefik.schema import ExtraServiceSchema
 from jinja2 import Template
 
+from ddb.config import config
+from ddb.feature.traefik.schema import ExtraServiceSchema
 from ...action import Action, InitializableAction
 from ...cache.removal import RemovalCacheSupport
+from ...config.migrations import MigrationsDotty
 from ...context import context
 from ...event import events
 from ...utils.file import write_if_different, copy_if_different, force_remove, FileUtils
@@ -187,7 +188,7 @@ class TraefikExtraServicesAction(InitializableAction):
 
     @staticmethod
     def _prepare_extra_service_data(extra_service, id_):
-        data = dict(config.data)
+        data = MigrationsDotty(dict(config.data))
         extra_service_data = dict(extra_service)
         extra_service_data['id'] = id_
         data['_local'] = extra_service_data
@@ -203,12 +204,12 @@ class TraefikExtraServicesAction(InitializableAction):
         if extra_service_data.get('redirect_to_https'):
             extra_service['https'] = True
         if extra_service_data.get('redirect_to_https') is None and extra_service['https'] is None:
-            extra_service_data['redirect_to_https'] = config.data.get('docker.reverse_proxy.redirect_to_https')
+            extra_service_data['redirect_to_https'] = config.data.get('jsonnet.docker.virtualhost.redirect_to_https')
 
         if not extra_service_data.get('path_prefix'):
             extra_service_data['redirect_to_path_prefix'] = False
         if extra_service['redirect_to_path_prefix'] is None:
             extra_service_data['redirect_to_path_prefix'] = \
-                config.data.get('docker.reverse_proxy.redirect_to_path_prefix')
+                config.data.get('jsonnet.docker.virtualhost.redirect_to_path_prefix')
 
         return extra_service_data, data
